@@ -6,13 +6,15 @@ from .evs_client import HuaweiEvsClient
 from .iam_client import HuaweiIamClient
 from .ims_client import HuaweiImsClient
 from .vpc_client import HuaweiVpcClient
+from .bss_client import HuaweiBssClient
 prod_mapper = {
     'ecs': HuaweiEcsClient,
     'eip': HuaweiEipClient,
     'evs': HuaweiEvsClient,
     'iam': HuaweiIamClient,
     'ims': HuaweiImsClient,
-    'vpc': HuaweiVpcClient
+    'vpc': HuaweiVpcClient,
+    'bss': HuaweiBssClient
 }
 
 
@@ -51,3 +53,8 @@ def hw_ims_client():
 @proxy
 def hw_vpc_client():
     return get_current_client('vpc')
+
+
+@proxy
+def hw_bss_client():
+    return get_current_client('bss')
